cd "/Users/bodet/Documents/Bodet UBC/POLI574/Data/"

use Party1.dta, clear   /*Liberal Party of Canada*/

*Level-1: Invidivual voters
*Level-2: Ridings AND/OR Day of campaign

sort riding idnum   /* let's start with level2=riding and local chances */
xtset riding idnum   /* though idnum is not a time variable! */
*
xtsum localchances /* some descriptive stats */

**********************
*p.64 - Three options*
**********************

xtreg localchances, mle /* intra-class correlation? rho */
*
xtmixed localchances || riding: , mle /* same results though xtmixed is slower */
*
which gllamm /* if error message, type "ssc install gllamm, replace" */
gllamm localchances, i(riding) nip(12) adapt /* "robust" can be added */

*********************************
*p.69 - Between-cluster variance*
*********************************

quietly xtmixed localchances || riding: , mle
est store m1
quietly xtmixed localchances, mle
lrtest m1   /* we could divide p-value by 2 if necessary... */

************************************************
*p.91 - Random-intercept models with covariates*
************************************************

xtsum idf soph atlant quebec prairie bc /* some descriptive stats: what's wrong? */

*******************************
*p.98 - Again... Three options*
*******************************

xtreg localchances idf soph, mle /* intra-class correlation? rho */
*
xtmixed localchances idf soph || riding: , mle /* same results though xtmixed is slower */
*
gllamm localchances idf soph, i(riding) adapt /* a lot slower but has certain nice options */
est store gllamm

********************************
*p.103 - Proportional Reduction*
********************************

xtmixed localchances || riding: , variance mle
xtmixed localchances idf soph || riding: , variance mle

di .0114+.0316    /* simple model */
di .0097+.0303    /* longer model */
di (.0430-.0400)/.0430   /* R2 of covariates at level1*/

di (.0114-.0097)/.0114 /* R2 level2 of covariates at level1 */
di (.0316-.0303)/.0316 /* R2 level1 of covariates at level1 */

********************************
*p.104 - Proportional Reduction*
********************************

xtmixed localchances || riding: , variance mle
xtmixed localchances atlant quebec prairie bc win result || riding: , variance mle

di .0114+.0316    /* simple model */
di .0038+.0315    /* longer model */
di (.0430-.0353)/.0430   /* R2 of covariates at level1*/

di (.0114-.0038)/.0114 /* R2 level2 of covariates at level1 */
di (.0316-.0315)/.0316 /* R2 level1 of covariates at level1 */

**********************
*p.122 - Hausman Test*
**********************

xtreg localchances idf soph atlant quebec prairie bc win result, fe   /* a series of fixed effects */
est store fixed
xtreg localchances idf soph atlant quebec prairie bc win result, re   /* what is the difference with mle? */
est store random

hausman fixed random

/*there is strong evidence of model misspecification. we should theoretically reject
the random-effects model in favour of the fixed-effects model. However, we are interested
in level-2 factors so we must estimate a random-effects model! Fortunately, there is a solution...*/

quietly foreach var of varlist idf soph {
egen mn_`var' = mean(`var'), by(riding)
}

xtreg localchances idf mn_idf soph mn_soph atlant quebec prairie bc win result, mle
testparm mn_*   /* keep the means! */

xtreg localchances idf mn_idf soph mn_soph atlant quebec prairie bc win result, fe   /* a series of fixed effects */
est store fixed
xtreg localchances idf mn_idf soph mn_soph atlant quebec prairie bc win result, re   /* what is the difference with mle? */
est store random

hausman fixed random

/*it seems to suggest (neg chi2) that we cannot reject the null hypothesis of correct specification*/

****************************************************
*p.142 - Separate linear regression for each riding*
****************************************************

reg localchances soph if riding==59028   /*why not "robust"? */

egen num=count(localchances), by(riding) /* we want enough obs to run the ols model */

statsby intercept=_b[_cons] slope=_b[soph], by(riding) saving(OLSData, replace): ///
regress localchances soph if num>5   /* let's isolate soph for now */
*
sort riding
merge riding using OLSData
drop _merge

twoway scatter slope intercept, xtitle(Intercept) ytitle(Slope)   /* highly correlated! so what? */

egen pickone = tag(riding)   /* to only look at one case per riding */
corr intercept slope if pickone==1, covariance

gen pred=intercept + slope*soph
sort riding soph
twoway (line pred soph, connect(ascending)), xtitle(Soph) ytitle(Fitted regression lines)
/* It is hard to argue for a systematic relationship... */

**********************************
*p.155 - Random-coefficient model*
**********************************

/* why xtmixed? Because it is more versatile! */
xtmixed localchances idf mn_idf soph mn_soph atlant quebec prairie bc win result || riding:, mle
estimates store ri
xtmixed localchances idf mn_idf soph mn_soph atlant quebec prairie bc win result || riding: idf soph, mle cov(unstructured)
estimates store rc

lrtest rc ri /* the random-coefficients model does 'fit better' */

**********************************************
*p.476 - Cross-random (or classified) effects*
**********************************************

xtmixed localchances || _all: R.riding || day:, variance mle

di (.0001)/(.0001+.0114+.0315)  /* time level */
di (.0114)/(.0001+.0114+.0315)  /* riding level */
di (.0315)/(.0001+.0114+.0315)  /* individal level */

/*It is a good idea to drop a level of analysis when its intra-class
correlation is basically zero. (see p.483 of Blais and Bodet) */

***********************************************
*Table 4 on page 485 of Blais and Bodet (2006)*
***********************************************

cd "/Users/bodet/Documents/Bodet UBC/POLI574/Data/"
use Party1.dta, clear   /*Liberal Party of Canada*/

*table 4, column 1...
xtmixed localchances idf soph atlant quebec prairie bc win result soph_win idf_win || riding: idf soph, mle variance cov(unstructured)

*adding the means of level-1 variables as instrumental variables
xtmixed localchances idf mn_idf soph mn_soph atlant quebec prairie bc win result soph_win idf_win || riding: idf soph, mle variance cov(unstructured)
